==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/pl/socksstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
<context>
    <name>SocksOptionsClass</name>
    <message>
        <source>Incoming Direct Connections</source>
        <translation>Bezpośrednie połączenie przychodzące</translation>
    </message>
    <message>
        <source>Disable direct connections</source>
        <translation>Wyłącz połączenie bezpośrednie</translation>
    </message>
    <message>
        <source>Port Forwarding</source>
        <translation>Przekierowanie portu</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Stream Proxy</source>
        <translation>Proxy strumienia</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>W górę</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>W dół</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Connection Proxy</source>
        <translation>Proxy połączenia</translation>
    </message>
    <message>
        <source>Use account connection proxy settings</source>
        <translation>Używaj ustawień połączenia konta dla proxy</translation>
    </message>
    <message>
        <source>Listening port:</source>
        <translation>Wybrany port:</translation>
    </message>
    <message>
        <source>Use proxy on account server</source>
        <translation>Używaj proxy na serwerze konta</translation>
    </message>
</context>
<context>
    <name>SocksStream</name>
    <message>
        <source>Stream destroyed</source>
        <translation>Strumień zniszczony</translation>
    </message>
    <message>
        <source>Unsupported stream mode</source>
        <translation>Nieobsługiwany tryb strumienia</translation>
    </message>
    <message>
        <source>Remote client cant connect to given hosts</source>
        <translation>Zdalny klient nie może podłączyć się do danych hostów</translation>
    </message>
    <message>
        <source>Failed to activate stream</source>
        <translation>Nie udało się otworzyc strumienia</translation>
    </message>
    <message>
        <source>Remote client is timed out to connect</source>
        <translation>Minął czas na odpowiedź zdalnego klienta</translation>
    </message>
    <message>
        <source>Failed to create hosts</source>
        <translation>Nie udało się utworzyć hosta</translation>
    </message>
    <message>
        <source>Direct connection not established</source>
        <translation>Nie ustanowiono połączenia bezpośredniego</translation>
    </message>
    <message>
        <source>Invalid host</source>
        <translation>Zły host</translation>
    </message>
    <message>
        <source>Cant connect to given hosts</source>
        <translation>Nie udało się połączyć z danymi hostemi</translation>
    </message>
    <message>
        <source>Failed to connect to host</source>
        <translation>Nie udało się połączyć z hostem</translation>
    </message>
</context>
<context>
    <name>SocksStreams</name>
    <message>
        <source>SOCKS5 Data Stream</source>
        <translation>Strumień danych SOCKS5</translation>
    </message>
    <message>
        <source>Allows to initiate SOCKS5 stream of data between two XMPP entities</source>
        <translation>Umożliwia zainicjowanie strumienia danych SOCKS5 między dwoma jednostkami XMPP</translation>
    </message>
    <message>
        <source>Supports the initiating of the SOCKS5 stream of data between two XMPP entities</source>
        <translation>Umożliwia zainicjowanie strumienia danych SOCKS5 między dwoma jednostkami XMPP</translation>
    </message>
    <message>
        <source>Data is transferred out-band over TCP or UDP connection</source>
        <translation>Dane wysłano wykorzystując połączenie TCP lub UDP</translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/pl/socksstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
<context>
    <name>SocksOptionsClass</name>
    <message>
        <source>Disable direct connections</source>
        <translation>Wyłącz połączenie bezpośrednie</translation>
    </message>
    <message>
        <source>Port Forwarding</source>
        <translation>Przekierowanie portu</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Stream Proxy</source>
        <translation>Proxy strumienia</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>W górę</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>W dół</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Connection Proxy</source>
        <translation>Proxy połączenia</translation>
    </message>
    <message>
        <source>Use account connection proxy settings</source>
        <translation>Używaj ustawień połączenia konta dla proxy</translation>
    </message>
    <message>
        <source>Listening port:</source>
        <translation>Wybrany port:</translation>
    </message>
    <message>
        <source>Use proxy on account server</source>
        <translation>Używaj proxy na serwerze konta</translation>
    </message>
    <message>
        <source>Outgoing Connections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect timeout:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incoming Connections</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SocksStream</name>
    <message>
        <source>Stream destroyed</source>
        <translation>Strumień zniszczony</translation>
    </message>
    <message>
        <source>Unsupported stream mode</source>
        <translation>Nieobsługiwany tryb strumienia</translation>
    </message>
    <message>
        <source>Remote client cant connect to given hosts</source>
        <translation>Zdalny klient nie może podłączyć się do danych hostów</translation>
    </message>
    <message>
        <source>Failed to activate stream</source>
        <translation>Nie udało się otworzyc strumienia</translation>
    </message>
    <message>
        <source>Failed to create hosts</source>
        <translation>Nie udało się utworzyć hosta</translation>
    </message>
    <message>
        <source>Direct connection not established</source>
        <translation>Nie ustanowiono połączenia bezpośredniego</translation>
    </message>
    <message>
        <source>Invalid host</source>
        <translation>Zły host</translation>
    </message>
    <message>
        <source>Cant connect to given hosts</source>
        <translation>Nie udało się połączyć z danymi hostemi</translation>
    </message>
    <message>
        <source>Failed to connect to host</source>
        <translation>Nie udało się połączyć z hostem</translation>
    </message>
</context>
<context>
    <name>SocksStreams</name>
    <message>
        <source>SOCKS5 Data Stream</source>
        <translation>Strumień danych SOCKS5</translation>
    </message>
    <message>
        <source>Allows to initiate SOCKS5 stream of data between two XMPP entities</source>
        <translation>Umożliwia zainicjowanie strumienia danych SOCKS5 między dwoma jednostkami XMPP</translation>
    </message>
    <message>
        <source>Supports the initiating of the SOCKS5 stream of data between two XMPP entities</source>
        <translation>Umożliwia zainicjowanie strumienia danych SOCKS5 między dwoma jednostkami XMPP</translation>
    </message>
    <message>
        <source>Data is transferred out-band over TCP or UDP connection</source>
        <translation>Dane wysłano wykorzystując połączenie TCP lub UDP</translation>
    </message>
</context>
</TS>
